import math

class Geodistance:
	
    def __init__(self):
        return

    def distance(self, lat1, lon1, lat2, lon2):
        
        # distance between latitudes
        # and longitudes
        dLat = (lat2 - lat1) * math.pi / 180.0
        dLon = (lon2 - lon1) * math.pi / 180.0

        # convert to radians
        lat1 = (lat1) * math.pi / 180.0
        lat2 = (lat2) * math.pi / 180.0

        # apply haversine formulae
        a = (pow(math.sin(dLat / 2), 2) +
            pow(math.sin(dLon / 2), 2) *
                math.cos(lat1) * math.cos(lat2))
        rad = 6371
        c = 2 * math.asin(math.sqrt(a))
        return int(rad * c)




# Always prefer setuptools over distutils
from setuptools import setup, find_packages

# To use a consistent encoding
from codecs import open
from os import path

# The directory containing this file
HERE = path.abspath(path.dirname(__file__))


# This call to setup() does all the work
setup(
    name="geodistance",
    version="0.2.0",
    description="Distance calculation library",
    long_description="A library that is used to calculate the distance between 2 coordinates <br /> **Installation** <br /> `pip install geodistance` <br /> **Get Started** <br /> Calculating distance between 2 coordinates <br /> `from geodistance import Geodistance` <br /> `length = Geodistance().distance(42.546245, 1.601554, 23.424076, 53.847818)` <br /> `print(length)`",
    long_description_content_type="text/markdown",
    url="https://geodistance.readthedocs.io/",
    author="Adebayo Adeoye",
    author_email="adeoyeadebayo18@gmail.com",
    license="MIT",
    classifiers=[
        "Intended Audience :: Developers",
        "License :: OSI Approved :: MIT License",
        "Programming Language :: Python",
        "Programming Language :: Python :: 3",
        "Programming Language :: Python :: 3.6",
        "Programming Language :: Python :: 3.7",
        "Programming Language :: Python :: 3.8",
        "Programming Language :: Python :: 3.9",
        "Operating System :: OS Independent"
    ],
    packages=["geodistance"],
    include_package_data=True,
    install_requires=[]
)